import pygame
import random

pygame.init()  #inicijalizacija modul

#velicina i boja prozora
SCREEN_WIDTH = 300
SCREEN_HEIGHT = 300
SCREEN_COLOR = (255,255,255)

#indikator da li je korisnik pobedio, izgubio ili je izjednaceno
WIN = 1
LOSE = 2
EQUAL = 3


#klasa koja predstavlja igraca
class Player(pygame.sprite.Sprite):


    font = pygame.font.SysFont("Comic Sans", 50) # font za ispis opcije igraca
    options = ["M", "K", "L"]  #opcije koje u igri moze da izabere igrace (makaze, kamen, list)
    color = (0,0,255)  # boja za prikaz izabrane opcije

    def __init__(self, postition):  # konstruktoru se prosedjuje pozicija prema kojoj
                                    # ce biti prikazana izabrana opcija igraca

        super().__init__()
        self.image = self.font.render("X", True, self.color) #pravljenje slike koja
                                                            # predstavlja izabranu opciju igraca
        self.rect = self.image.get_rect(topleft=postition) #pravljenje pridruzenog  pravugaonika
        self.value ="X"  #izabrana opcija igraca

#klasa koja predstavlja korisnika
class UserPlayer(Player):

    def __init__(self, postition):
        super().__init__(postition)

    #metod za azuriranje opcije
    def update(self, value):

        self.value = value
        self.image = self.font.render(self.value,  True, self.color)
        self.rect = self.image.get_rect(topleft=self.rect.topleft)

    #metod za proveru da li je korisnik pobedion ili izgubio od racunara
    def fin(self, computer):

        if self.value == computer.value:
            return  EQUAL

        if (self.value =="M" and computer.value=="L") or \
            (self.value == "K" and computer.value == "M") or \
            (self.value == "L" and computer.value == "L"):
            return WIN

        return  LOSE

#klasa koja predstavlja racunar
class ComputerPlayer(Player):

    def __init__(self, postition):
        super().__init__(postition)

    #metod za azuriranje opcije
    #novi izbor se nasumicno bira
    def update(self):

        self.value = self.options[random.randint(0, len(self.options)-1)]
        self.image = self.font.render(self.value, True, self.color)
        self.rect = self.image.get_rect(topleft=self.rect.topleft)


#pravljenje prozora za prikaz
screen = pygame.display.set_mode((SCREEN_WIDTH, SCREEN_HEIGHT))

screen.fill(SCREEN_COLOR)  #postavljanje boje prozora
pygame.display.set_caption("Makaze kamen list") #postavljanje naslova prozora

running = True #promenljiva za kontrolu petlje igre

#pravljenje igraca - korisnik
user = UserPlayer((SCREEN_WIDTH/2,SCREEN_HEIGHT/2))

#pravljenje igraca - racunar
computer = ComputerPlayer((10,10))

#pravljenje grupe koja ce sadrzati sve sprajtove
all_sprites = pygame.sprite.Group()

#dodavanje igraca u grupu
all_sprites.add(user)
all_sprites.add(computer)

#postavljanje fonta koji ce biti koriscen za prikaz poruke
font = pygame.font.SysFont("Comic Sans", 35)

message="Igraj (K,M,N)" #pravljenje poruke
text = font.render(message, True, (0, 255, 0))     # pravljenje slike za poruku

# iscrtavanje svakog sprajta
all_sprites.draw(screen)
#iscrtavanje poruke
screen.blit(text, text.get_rect(bottomright=(SCREEN_WIDTH, SCREEN_HEIGHT)))

# azurira sadrzaj za prikazivanje
pygame.display.update()

#petlja igre (tj. glavna petlja)
while running:

    #obrada dogadjaja
    for event in pygame.event.get():

        if event.type == pygame.QUIT:
            running = False

        elif event.type == pygame.KEYDOWN:
            if event.key == pygame.K_ESCAPE:
                running = False
                message="Bye-Bye"

            #provera da li je korisnik izabrao opciju M (makaze)
            if event.key ==  pygame.K_m:
                user.update("M") #azuriranje opcije korisnika
                computer.update() #azuriranje opcije igraca

                #proveda da li je korisnik pobedio ili izgubio
                # i odredjivanje koja ce se poruka prikazati shodno ishodu
                if user.fin(computer) == WIN:
                    message="POBEDA"
                elif user.fin(computer) == EQUAL:
                    message = "IZJEDNACENO"
                else:
                    message="GUBITAK"

            #bojenje prozora
            screen.fill(SCREEN_COLOR)
            #iscrtavanje sprajtova u prozoru
            all_sprites.draw(screen)
            #pravljenje slike za poruku
            text = font.render(message, True, (0,255,0))
            # iscrtavanje poruke u prozoru
            screen.blit(text, text.get_rect(bottomright=(SCREEN_WIDTH,SCREEN_HEIGHT)))

            # azurira sadrzaj za prikazivanje
            pygame.display.update()

pygame.quit()